# insarpy


[![image](https://img.shields.io/pypi/v/insarpy.svg)](https://pypi.python.org/pypi/insarpy)
[![image](https://img.shields.io/conda/vn/conda-forge/insarpy.svg)](https://anaconda.org/conda-forge/insarpy)


**A python package for interactive mapping.**


-   Free software: MIT license
-   Documentation: https://Abubakr-Abdelrahman.github.io/insarpy
    

## Features

-   TODO
